@@ -9,10 +9,10 @@ from scintillant.outs import Dictionary
 from loguru import logger
 
 
-class Vault(BaseModel, metaclass=ABC):
+class Vault(BaseModel):
 
-    @abstractmethod
     @classmethod
+    @abstractmethod
     def create(cls, data: SkillRequestType):
         pass
 
@@ -70,6 +70,8 @@ class ContextUpdater:
                 raise Exception(f"State {state} not registered!")
             else:
                 self.states[state](self)
+        # Save vault updated data
+        self.context['__vault__'] = self.vault.dict()
 
     def execute_now(self, func: Callable) -> None:
         self.next_state = func
